@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2013 Codership Oy <info@codership.com>
+// Copyright (C) 2013-2018 Codership Oy <info@codership.com>
 //
 
 #ifndef GALERA_KEY_ENTRY_NG_HPP
@@ -18,21 +18,21 @@ namespace galera
             : refs_(), key_(key)
         {
             std::fill(&refs_[0],
-                      &refs_[KeySet::Key::P_LAST],
-                      reinterpret_cast<TrxHandle*>(NULL));
+                      &refs_[KeySet::Key::TYPE_MAX],
+                      static_cast<TrxHandle*>(NULL));
         }
 
         KeyEntryNG(const KeyEntryNG& other)
         : refs_(), key_(other.key_)
         {
             std::copy(&other.refs_[0],
-                      &other.refs_[KeySet::Key::P_LAST],
+                      &other.refs_[KeySet::Key::TYPE_MAX],
                       &refs_[0]);
         }
 
         const KeySet::KeyPart& key() const { return key_; }
 
-        void ref(KeySet::Key::Prefix p, const KeySet::KeyPart& k,
+        void ref(wsrep_key_type_t p, const KeySet::KeyPart& k,
                  TrxHandle* trx)
         {
             assert(0 == refs_[p] ||
@@ -42,7 +42,7 @@ namespace galera
             key_ = k;
         }
 
-        void unref(KeySet::Key::Prefix p, TrxHandle* trx)
+        void unref(wsrep_key_type_t p, TrxHandle* trx)
         {
             assert(refs_[p] != NULL);
 
@@ -61,7 +61,7 @@ namespace galera
         {
             bool ret(refs_[0] != NULL);
 
-            for (int i(1); false == ret && i <= KeySet::Key::P_LAST; ++i)
+            for (int i(1); false == ret && i <= KeySet::Key::TYPE_MAX; ++i)
             {
                 ret = (refs_[i] != NULL);
             }
@@ -69,7 +69,7 @@ namespace galera
             return ret;
         }
 
-        const TrxHandle* ref_trx(KeySet::Key::Prefix p) const
+        const TrxHandle* ref_trx(int const p) const
         {
             return refs_[p];
         }
@@ -99,7 +99,7 @@ namespace galera
 
     private:
 
-        TrxHandle*      refs_[KeySet::Key::P_LAST + 1];
+        TrxHandle*      refs_[KeySet::Key::TYPE_MAX + 1];
         KeySet::KeyPart key_;
 
 #ifndef NDEBUG
