@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2010-2020 Codership Oy <info@codership.com>
+// Copyright (C) 2010-2021 Codership Oy <info@codership.com>
 //
 
 #include "replicator_smm.hpp"
@@ -294,18 +294,8 @@ ReplicatorSMM::donate_sst(void* const         recv_ctx,
     wsrep_cb_status const err(sst_donate_cb_(app_ctx_, recv_ctx,
                                              streq.sst_req(), streq.sst_len(),
                                              &state_id, 0, 0, bypass));
-
-    /* The fix to codership/galera#284 may break backward comatibility due to
-     * different (now correct) interpretation of retrun value. Default to old
-     * interpretation which is forward compatible with the new one. */
-#if NO_BACKWARD_COMPATIBILITY
     wsrep_seqno_t const ret
         (WSREP_CB_SUCCESS == err ? state_id.seqno : -ECANCELED);
-#else
-    wsrep_seqno_t const ret
-        (int(err) >= 0 ? state_id.seqno : int(err));
-#endif /* NO_BACKWARD_COMPATIBILITY */
-
     if (ret < 0)
     {
         log_error << "SST " << (bypass ? "bypass " : "") << "failed: " << err;
@@ -367,9 +357,20 @@ void ReplicatorSMM::process_state_req(void*       recv_ctx,
             {
                 log_info << "IST request: " << istr;
 
+                struct sgl
+                {
+                    gcache::GCache& gcache_;
+                    bool            unlock_;
+
+                    sgl(gcache::GCache& cache) : gcache_(cache), unlock_(false){}
+                    ~sgl() { if (unlock_) gcache_.seqno_unlock(); }
+                }
+                seqno_lock_guard(gcache_);
+
                 try
                 {
                     gcache_.seqno_lock(istr.last_applied() + 1);
+                    seqno_lock_guard.unlock_ = true;
                 }
                 catch(gu::NotFound& nf)
                 {
@@ -405,6 +406,9 @@ void ReplicatorSMM::process_state_req(void*       recv_ctx,
                                          istr.last_applied() + 1,
                                          cc_seqno_,
                                          protocol_version_);
+
+                        // seqno will be unlocked when sender exists
+                        seqno_lock_guard.unlock_ = false;
                     }
                     catch (gu::Exception& e)
                     {
@@ -711,7 +715,7 @@ ReplicatorSMM::request_state_transfer (void* recv_ctx,
                 commit_monitor_.set_initial_position(-1);
                 commit_monitor_.set_initial_position(sst_seqno_);
             }
-
+            last_st_type_ = ST_TYPE_SST;
             log_debug << "Installed new state: " << state_uuid_ << ":"
                       << sst_seqno_;
         }
@@ -721,6 +725,9 @@ ReplicatorSMM::request_state_transfer (void* recv_ctx,
         assert (state_uuid_ == group_uuid);
     }
 
+    // Clear seqno from state file. Otherwise if node gets killed
+    // during IST, it may recover to incorrect position.
+    st_.set(state_uuid_, WSREP_SEQNO_UNDEFINED, safe_to_bootstrap_);
     st_.mark_safe();
 
     if (req->ist_len() > 0)
@@ -734,7 +741,7 @@ ReplicatorSMM::request_state_transfer (void* recv_ctx,
             ist_receiver_.ready();
             recv_IST(recv_ctx);
             sst_seqno_ = ist_receiver_.finished();
-
+            last_st_type_ = ST_TYPE_IST;
             // Note: apply_monitor_ must be drained to avoid race between
             // IST appliers and GCS appliers, GCS action source may
             // provide actions that have already been applied.
@@ -757,6 +764,7 @@ void ReplicatorSMM::recv_IST(void* recv_ctx)
     {
         TrxHandle* trx(0);
         int err;
+        bool fail(false);
         try
         {
             if ((err = ist_receiver_.recv(&trx)) == 0)
@@ -782,7 +790,15 @@ void ReplicatorSMM::recv_IST(void* recv_ctx)
                     // processed on donor, just adjust states here
                     trx->set_state(TrxHandle::S_REPLICATING);
                     trx->set_state(TrxHandle::S_CERTIFYING);
-                    apply_trx(recv_ctx, trx);
+                    try
+                    {
+                        apply_trx(recv_ctx, trx);
+                    }
+                    catch (...)
+                    {
+                         st_.mark_corrupt();
+                         throw;
+                    }
                     GU_DBUG_SYNC_WAIT("recv_IST_after_apply_trx");
                 }
             }
@@ -792,15 +808,25 @@ void ReplicatorSMM::recv_IST(void* recv_ctx)
             }
             trx->unref();
         }
-        catch (gu::Exception& e)
+        catch (std::exception& e)
         {
             log_fatal << "receiving IST failed, node restart required: "
                       << e.what();
+            fail = true;
+        }
+        catch (...)
+        {
+            log_fatal << "receiving IST failed, node restart required: "
+                         "unknown exception.";
+            fail = true;
+        }
+
+        if (fail)
+        {
             if (trx)
             {
                 log_fatal << "failed trx: " << *trx;
             }
-            st_.mark_corrupt();
             abort();
         }
     }
