@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2018 Codership Oy <info@codership.com>
+ * Copyright (C) 2009-2020 Codership Oy <info@codership.com>
  */
 
 #include "GCache.hpp"
@@ -22,12 +22,13 @@ namespace gcache
         mallocs  = 0;
         reallocs = 0;
 
-        seqno_locked   = SEQNO_NONE;
+        gid            = gu::UUID();
         seqno_max      = SEQNO_NONE;
         seqno_released = SEQNO_NONE;
-        gid            = gu::UUID();
+        seqno_locked   = SEQNO_MAX;
+        seqno_locked_count = 0;
 
-        seqno2ptr.clear();
+        seqno2ptr.clear(SEQNO_NONE);
 
 #ifndef NDEBUG
         buf_tracker.clear();
@@ -39,8 +40,7 @@ namespace gcache
         config    (cfg),
         params    (config, data_dir),
         mtx       (),
-        cond      (),
-        seqno2ptr (),
+        seqno2ptr (SEQNO_NONE),
         gid       (),
         mem       (params.mem_size(), seqno2ptr, params.debug()),
         rb        (params.rb_name(), params.rb_size(), seqno2ptr, gid,
@@ -54,10 +54,11 @@ namespace gcache
         mallocs   (0),
         reallocs  (0),
         frees     (0),
-        seqno_locked(SEQNO_NONE),
-        seqno_max   (seqno2ptr.empty() ?
-                     SEQNO_NONE : seqno2ptr.rbegin()->first),
-        seqno_released(seqno_max)
+        seqno_max     (seqno2ptr.empty() ?
+                       SEQNO_NONE : seqno2ptr.index_back()),
+        seqno_released(seqno_max),
+        seqno_locked  (SEQNO_MAX),
+        seqno_locked_count(0)
 #ifndef NDEBUG
         ,buf_tracker()
 #endif
