@@ -7,6 +7,10 @@
 #ifndef _gcache_memops_hpp_
 #define _gcache_memops_hpp_
 
+#include <gu_arch.h>
+#include <gu_macros.h>
+#include <stdint.h>
+
 namespace gcache
 {
     struct BufferHeader;
@@ -14,7 +18,6 @@ namespace gcache
     class MemOps
     {
     public:
-
         /* although size value passed to GCache should be representable by
          * a signed integer type, internally the buffer allocated will also
          * incur header overhead, so it has to be represented by unsigned int.
@@ -41,6 +44,24 @@ namespace gcache
 
         virtual void
         reset   ()                        = 0;
+
+        /* GCache 3.x is not supposed to be portable between platforms */
+        static size_type const ALIGNMENT  = GU_WORD_BYTES;
+
+        static inline size_type align_size(size_type s)
+        {
+            return align<size_type>(s);
+        }
+
+        static inline uint8_t* align_ptr(uint8_t* p)
+        {
+            return reinterpret_cast<uint8_t*>(align<uintptr_t>(uintptr_t(p)));
+        }
+
+    private:
+
+        template <typename T>
+        static inline T align(T s) { return GU_ALIGN(s, ALIGNMENT); }
     };
 }
 
