@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009-2014 Codership Oy <info@codership.com>
+ * Copyright (C) 2009-2019 Codership Oy <info@codership.com>
  */
 
 /*!
@@ -30,6 +30,8 @@
 #include <list>
 #include <utility>
 
+#include <boost/function.hpp>
+
 // Declarations
 namespace gcomm
 {
@@ -170,22 +172,33 @@ class gcomm::ProtoDownMeta
 public:
     ProtoDownMeta(const uint8_t user_type = 0xff,
                   const Order   order     = O_SAFE,
-                  const UUID&   uuid      = UUID::nil(),
+                  const UUID&   source      = UUID::nil(),
                   const int     segment   = 0) :
         user_type_ (user_type),
         order_     (order),
-        source_    (uuid),
+        source_    (source),
+        target_    (UUID::nil()),
         segment_   (segment)
     { }
 
+    ProtoDownMeta(const UUID& target)
+        : user_type_(0xff)
+        , order_ (O_SAFE)
+        , source_(UUID::nil())
+        , target_(target)
+        , segment_(0)
+    { }
+
     uint8_t     user_type() const { return user_type_; }
     Order       order()     const { return order_;     }
     const UUID& source()    const { return source_;    }
+    const UUID& target()    const { return target_;    }
     int         segment()   const { return segment_;   }
 private:
     const uint8_t user_type_;
     const Order   order_;
     const UUID    source_;
+    const UUID    target_;
     const int     segment_;
 };
 
@@ -194,6 +207,8 @@ class gcomm::Protolay
 public:
     typedef Map<UUID, gu::datetime::Date> EvictList;
 
+    typedef boost::function<void()> sync_param_cb_t;
+
     virtual ~Protolay() {}
 
     virtual void connect(bool) { }
@@ -312,7 +327,8 @@ public:
 
     void evict(const UUID& uuid)
     {
-        evict_list_.insert(std::make_pair(uuid, gu::datetime::Date::now()));
+        evict_list_.insert(
+            std::make_pair(uuid, gu::datetime::Date::monotonic()));
         handle_evict(uuid);
         for (CtxList::iterator i(down_context_.begin());
              i != down_context_.end(); ++i)
@@ -376,7 +392,8 @@ public:
         return gu::datetime::Date::max();
     }
 
-    virtual bool set_param(const std::string& key, const std::string& val)
+    virtual bool set_param(const std::string& key, const std::string& val, 
+                           sync_param_cb_t& sync_param_cb)
     {
         return false;
     }
