@@ -321,18 +321,13 @@ void gcomm::pc::Proto::shift_to(const State s)
     // State graph
     static const bool allowed[S_MAX][S_MAX] = {
 
-        // Closed
-        { false, false,  false, false, false, true },
-        // States exch
-        { true,  false, true,  false, true,  true  },
-        // Install
-        { true,  false, false, true,  true,  true  },
-        // Prim
-        { true,  false, false, false, true,  true  },
-        // Trans
-        { true,  true,  false, false, false, true  },
-        // Non-prim
-        { true,  false,  false, true, true,  true  }
+        // Cl     S-E    IN     P      Trans  N-P
+        {  false, false, false, false, false, true  }, // Closed
+        {  true,  false, true,  false, true,  true  }, // States exch
+        {  true,  false, false, true,  true,  true  }, // Install
+        {  true,  false, false, false, true,  true  }, // Prim
+        {  true,  true,  false, false, false, true  }, // Trans
+        {  true,  false, false,  true, true,  true  }  // Non-prim
     };
 
 
@@ -476,20 +471,40 @@ static bool have_weights(const gcomm::NodeList& node_list,
     return true;
 }
 
+static bool node_list_intersection_comp(const gcomm::NodeList::value_type& vt1,
+                                        const gcomm::NodeList::value_type& vt2)
+{
+    return (vt1.first < vt2.first);
+}
+
+static gcomm::NodeList node_list_intersection(const gcomm::NodeList& nl1,
+                                              const gcomm::NodeList& nl2)
+{
+    gcomm::NodeList ret;
+    std::set_intersection(nl1.begin(), nl1.end(), nl2.begin(), nl2.end(),
+                          std::inserter(ret, ret.begin()),
+                          node_list_intersection_comp);
+    return ret;
+}
 
 bool gcomm::pc::Proto::have_quorum(const View& view, const View& pc_view) const
 {
+    // Compare only against members and left which were part of the pc_view.
+    gcomm::NodeList memb_intersection(
+        node_list_intersection(view.members(), pc_view.members()));
+    gcomm::NodeList left_intersection(
+        node_list_intersection(view.left(), pc_view.members()));
     if (have_weights(view.members(), instances_) &&
         have_weights(view.left(), instances_)    &&
         have_weights(pc_view.members(), instances_))
     {
-        return (weighted_sum(view.members(), instances_) * 2
-                + weighted_sum(view.left(), instances_) >
+        return (weighted_sum(memb_intersection, instances_) * 2
+                + weighted_sum(left_intersection, instances_) >
                 weighted_sum(pc_view.members(), instances_));
     }
     else
     {
-        return (view.members().size()*2 + view.left().size() >
+        return (memb_intersection.size()*2 + left_intersection.size() >
                 pc_view.members().size());
     }
 }
@@ -497,17 +512,22 @@ bool gcomm::pc::Proto::have_quorum(const View& view, const View& pc_view) const
 
 bool gcomm::pc::Proto::have_split_brain(const View& view) const
 {
+    // Compare only against members and left which were part of the pc_view.
+    gcomm::NodeList memb_intersection(
+        node_list_intersection(view.members(), pc_view_.members()));
+    gcomm::NodeList left_intersection(
+        node_list_intersection(view.left(), pc_view_.members()));
     if (have_weights(view.members(), instances_)  &&
         have_weights(view.left(), instances_)     &&
         have_weights(pc_view_.members(), instances_))
     {
-        return (weighted_sum(view.members(), instances_) * 2
-                + weighted_sum(view.left(), instances_) ==
+        return (weighted_sum(memb_intersection, instances_) * 2
+                + weighted_sum(left_intersection, instances_) ==
                 weighted_sum(pc_view_.members(), instances_));
     }
     else
     {
-        return (view.members().size()*2 + view.left().size() ==
+        return (memb_intersection.size()*2 + left_intersection.size() ==
                 pc_view_.members().size());
     }
 }
@@ -523,7 +543,7 @@ void gcomm::pc::Proto::handle_trans(const View& view)
     log_debug << self_id() << " \n\n current view " << current_view_
               << "\n\n next view " << view
               << "\n\n pc view " << pc_view_;
-
+    log_debug << *this;
     if (have_quorum(view, pc_view_) == false)
     {
         if (closing_ == false && ignore_sb_ == true && have_split_brain(view))
